@@ -331,6 +331,8 @@ class NBConvertEngine(Engine):
         nb_man,
         kernel_name,
         log_output=False,
+        stdout_file=None,
+        stderr_file=None,
         start_timeout=60,
         execution_timeout=None,
         **kwargs
@@ -341,7 +343,8 @@ class NBConvertEngine(Engine):
         Args:
             nb (NotebookNode): Executable notebook object.
             kernel_name (str): Name of kernel to execute the notebook against.
-            log_output (bool): Flag for whether or not to write notebook output to stderr.
+            log_output (bool): Flag for whether or not to write notebook output to the
+                               configured logger.
             start_timeout (int): Duration to wait for kernel start-up.
             execution_timeout (int): Duration to wait before failing execution (default: never).
 
@@ -355,14 +358,17 @@ class NBConvertEngine(Engine):
         safe_kwargs = remove_args(['timeout', 'startup_timeout'], **kwargs)
 
         # Nicely handle preprocessor arguments prioritizing values set by engine
-        preprocessor = PapermillExecutePreprocessor(
-            **merge_kwargs(safe_kwargs,
-                           timeout=execution_timeout if execution_timeout else kwargs.get('timeout'),
-                           startup_timeout=start_timeout,
-                           kernel_name=kernel_name,
-                           log=logger))
-
-        preprocessor.log_output = log_output
+        final_kwargs = merge_kwargs(
+            safe_kwargs,
+            timeout=execution_timeout if execution_timeout else kwargs.get('timeout'),
+            startup_timeout=start_timeout,
+            kernel_name=kernel_name,
+            log=logger,
+            log_output=log_output,
+            stdout_file=stdout_file,
+            stderr_file=stderr_file,
+        )
+        preprocessor = PapermillExecutePreprocessor(**final_kwargs)
         preprocessor.preprocess(nb_man, safe_kwargs)
 
 
