@@ -49,21 +49,21 @@ try:
 except ImportError:
     GCSFileSystem = missing_dependency_generator("gcsfs", "gcs")
 
-# Handle newer and older gcsfs versions
-try:
+
+def fallback_gs_is_retriable(e):
     try:
-        from gcsfs.utils import HttpError as GCSHttpError
-    except ImportError:
-        from gcsfs.utils import HtmlError as GCSHttpError
-except ImportError:
-    # Fall back to a sane import if gcsfs is missing
-    GCSHttpError = Exception
+        print(e.code)
+        return e.code is None or e.code == 429
+    except AttributeError:
+        print(e)
+        return False
+
 
 try:
-    from gcsfs.utils import RateLimitException as GCSRateLimitException
+    # Default to gcsfs library's retry logic
+    from gcsfs.utils import is_retriable as gs_is_retriable
 except ImportError:
-    # Fall back to GCSHttpError when using older library
-    GCSRateLimitException = GCSHttpError
+    gs_is_retriable = fallback_gs_is_retriable
 
 try:
     FileNotFoundError
@@ -101,7 +101,13 @@ class PapermillIO(object):
 
     def write(self, buf, path, extensions=['.ipynb', '.json']):
         if path == '-':
-            return sys.stdout.write(buf)
+            try:
+                # Python 3
+                return sys.stdout.buffer.write(buf.encode('utf-8'))
+            except AttributeError:
+                # Python 2: add explicit utf-8 encoding
+                # https://github.com/nteract/papermill/issues/420
+                return sys.stdout.write(buf.encode('utf-8'))
 
         # Usually no return object here
         if not fnmatch.fnmatch(os.path.basename(path), '*.*'):
@@ -308,16 +314,12 @@ class GCSHandler(object):
             try:
                 with self._get_client().open(path, 'w') as f:
                     return f.write(buf)
-            except (GCSHttpError, GCSRateLimitException) as e:
+            except Exception as e:
                 try:
-                    # If code is assigned but unknown, optimistically retry
-                    if e.code is None or e.code == 429:
-                        raise PapermillRateLimitException(e.message)
+                    message = e.message
                 except AttributeError:
-                    try:
-                        message = e.message
-                    except AttributeError:
-                        message = "Generic exception {} raised, retrying".format(type(e))
+                    message = "Generic exception {} raised".format(type(e))
+                if gs_is_retriable(e):
                     raise PapermillRateLimitException(message)
                 # Reraise the original exception without retries
                 raise
